@@ -57,16 +57,16 @@ PYLSP_REQVER = '>=1.4.1'
 PYLSP_BLACK_REQVER = '>=1.2.0'
 PYLS_SPYDER_REQVER = '>=0.4.0'
 PYXDG_REQVER = '>=0.26'
-PYZMQ_REQVER = '>=17'
+PYZMQ_REQVER = '>=22.1.0'
 QDARKSTYLE_REQVER = '>=3.0.2'
 QSTYLIZER_REQVER = '>=0.1.10'
 QTAWESOME_REQVER = '>=1.0.2'
 QTCONSOLE_REQVER = '>=5.3.0'
-QTPY_REQVER = '>=2.0.1'
+QTPY_REQVER = '>=2.1.0'
 RTREE_REQVER = '>=0.9.7'
 SETUPTOOLS_REQVER = '>=49.6.0'
 SPHINX_REQVER = '>=0.6.6'
-SPYDER_KERNELS_REQVER = '>=2.3.0;<2.4.0'
+SPYDER_KERNELS_REQVER = '>=2.3.1;<2.4.0'
 TEXTDISTANCE_REQVER = '>=4.2.0'
 THREE_MERGE_REQVER = '>=0.1.1'
 # None for pynsist install for now
