@@ -145,7 +145,8 @@ class LanguageServerProvider(SpyderCompletionProvider):
         """Stop all heartbeats"""
         for language in self.clients_hearbeat:
             try:
-                self.clients_hearbeat[language].stop()
+                if self.clients_hearbeat[language] is not None:
+                    self.clients_hearbeat[language].stop()
             except (TypeError, KeyError, RuntimeError):
                 pass
 
@@ -654,8 +655,14 @@ class LanguageServerProvider(SpyderCompletionProvider):
                     language_client['instance'].disconnect()
                 except TypeError:
                     pass
+                try:
+                    if self.clients_hearbeat[language] is not None:
+                        self.clients_hearbeat[language].stop()
+                except (TypeError, KeyError, RuntimeError):
+                    pass
                 language_client['instance'].stop()
             language_client['status'] = self.STOPPED
+            self.sig_stop_completions.emit(language)
 
     def receive_response(self, response_type, response, language, req_id):
         if req_id in self.requests:
@@ -756,8 +763,13 @@ class LanguageServerProvider(SpyderCompletionProvider):
 
         # Autoformatting configuration
         formatter = self.get_conf('formatting')
-        formatter = 'pyls_black' if formatter == 'black' else formatter
-        formatters = ['autopep8', 'yapf', 'pyls_black']
+
+        # This is necessary because PyLSP third-party plugins can only be
+        # disabled with their module name.
+        formatter = 'pylsp_black' if formatter == 'black' else formatter
+
+        # Enabling/disabling formatters
+        formatters = ['autopep8', 'yapf', 'pylsp_black']
         formatter_options = {
             fmt: {
                 'enabled': fmt == formatter
@@ -765,8 +777,12 @@ class LanguageServerProvider(SpyderCompletionProvider):
             for fmt in formatters
         }
 
-        if formatter == 'pyls_black':
-            formatter_options['pyls_black']['line_length'] = cs_max_line_length
+        # Setting max line length for formatters
+        # The autopep8 plugin shares the same maxLineLength value with the
+        # pycodestyle one. That's why it's not necessary to set it here.
+        # NOTE: We need to use `black` and not `pylsp_black` because that's
+        # the options' namespace of that plugin.
+        formatter_options['black'] = {'line_length': cs_max_line_length}
 
         # PyLS-Spyder configuration
         group_cells = self.get_conf(
@@ -787,7 +803,7 @@ class LanguageServerProvider(SpyderCompletionProvider):
             environment = None
             env_vars = None
         else:
-            environment = self.get_conf('custom_interpreter',
+            environment = self.get_conf('executable',
                                         section='main_interpreter')
             env_vars = os.environ.copy()
             # external interpreter should not use internal PYTHONPATH
@@ -830,6 +846,7 @@ class LanguageServerProvider(SpyderCompletionProvider):
         python_config['host'] = host
         python_config['port'] = port
 
+        # Updating options
         plugins = python_config['configurations']['pylsp']['plugins']
         plugins['pycodestyle'].update(pycodestyle)
         plugins['pyflakes'].update(pyflakes)
@@ -840,8 +857,6 @@ class LanguageServerProvider(SpyderCompletionProvider):
         plugins['jedi_signature_help'].update(jedi_signature_help)
         plugins['jedi_definition'].update(jedi_definition)
         plugins['preload']['modules'] = self.get_conf('preload_modules')
-
-        for formatter in formatters:
-            plugins[formatter] = formatter_options[formatter]
+        plugins.update(formatter_options)
 
         return python_config
