@@ -108,8 +108,8 @@ class ConsoleWidget(PluginMainWidget):
         Example `{'name': str, 'ignore_unknown': bool}`.
     """
 
-    def __init__(self, name, plugin, parent=None, configuration=None):
-        super().__init__(name, plugin, parent, configuration=configuration)
+    def __init__(self, name, plugin, parent=None):
+        super().__init__(name, plugin, parent)
 
         logger.info("Initializing...")
 
@@ -117,17 +117,30 @@ class ConsoleWidget(PluginMainWidget):
         self.error_traceback = ''
         self.dismiss_error = False
 
+        # Header message
+        message = _(
+            "Spyder Internal Console\n\n"
+            "This console is used to report application\n"
+            "internal errors and to inspect Spyder\n"
+            "internals with the following commands:\n"
+            "  spy.app, spy.window, dir(spy)\n\n"
+            "Please do not use it to run your code\n\n"
+        )
+
+        # Options that come from the command line
+        cli_options = plugin.get_command_line_options()
+        profile = cli_options.profile
+        multithreaded = cli_options.multithreaded
+
         # Widgets
         self.dialog_manager = DialogManager()
         self.error_dlg = None
         self.shell = InternalShell(  # TODO: Move to use SpyderWidgetMixin?
-            parent=parent,
-            namespace=self.get_conf('namespace', {}),
-            commands=self.get_conf('commands', []),
-            message=self.get_conf('message', ''),
+            commands=[],
+            message=message,
             max_line_count=self.get_conf('max_line_count'),
-            profile=self.get_conf('profile', False),
-            multithreaded=self.get_conf('multithreaded', False),
+            profile=profile,
+            multithreaded=multithreaded,
         )
         self.find_widget = FindReplace(self)
 
