@@ -8,14 +8,13 @@
 
 # Third party imports
 from qtpy.QtCore import Slot
-from qtpy.QtWidgets import QVBoxLayout
 
 # Local imports
+from spyder.api.plugin_registration.decorators import (
+    on_plugin_available, on_plugin_teardown)
 from spyder.api.translations import get_translation
 from spyder.api.plugins import SpyderDockablePlugin, Plugins
-from spyder.py3compat import is_text_string
-from spyder.utils.icon_manager import ima
-from spyder.plugins.outlineexplorer.widgets import OutlineExplorerWidget
+from spyder.plugins.outlineexplorer.main_widget import OutlineExplorerWidget
 
 # Localization
 _ = get_translation('spyder')
@@ -24,7 +23,7 @@ _ = get_translation('spyder')
 class OutlineExplorer(SpyderDockablePlugin):
     NAME = 'outline_explorer'
     CONF_SECTION = 'outline_explorer'
-    REQUIRES = [Plugins.Completions]
+    REQUIRES = [Plugins.Completions, Plugins.Editor]
     OPTIONAL = []
 
     CONF_FILE = False
@@ -32,7 +31,8 @@ class OutlineExplorer(SpyderDockablePlugin):
 
     # ---- SpyderDockablePlugin API
     # ------------------------------------------------------------------------
-    def get_name(self) -> str:
+    @staticmethod
+    def get_name() -> str:
         """Return widget title."""
         return _('Outline Explorer')
 
@@ -44,17 +44,43 @@ class OutlineExplorer(SpyderDockablePlugin):
         """Return the outline explorer icon."""
         return self.create_icon('outline_explorer')
 
-    def register(self):
-        completions = self.get_plugin(Plugins.Completions)
+    def on_initialize(self):
         if self.main:
             self.main.restore_scrollbar_position.connect(
                 self.restore_scrollbar_position)
 
+    @on_plugin_available(plugin=Plugins.Completions)
+    def on_completions_available(self):
+        completions = self.get_plugin(Plugins.Completions)
+
         completions.sig_language_completions_available.connect(
             self.start_symbol_services)
         completions.sig_stop_completions.connect(
             self.stop_symbol_services)
 
+    @on_plugin_available(plugin=Plugins.Editor)
+    def on_editor_available(self):
+        editor = self.get_plugin(Plugins.Editor)
+
+        editor.sig_open_files_finished.connect(
+            self.update_all_editors)
+
+    @on_plugin_teardown(plugin=Plugins.Completions)
+    def on_completions_teardown(self):
+        completions = self.get_plugin(Plugins.Completions)
+
+        completions.sig_language_completions_available.disconnect(
+            self.start_symbol_services)
+        completions.sig_stop_completions.disconnect(
+            self.stop_symbol_services)
+
+    @on_plugin_teardown(plugin=Plugins.Editor)
+    def on_editor_teardown(self):
+        editor = self.get_plugin(Plugins.Editor)
+
+        editor.sig_open_files_finished.disconnect(
+            self.update_all_editors)
+
     #------ Public API ---------------------------------------------------------
     def restore_scrollbar_position(self):
         """Restoring scrollbar position after main window is visible"""
